if {[string equal $::tcl_platform(platform) unix]} {
    package ifneeded filesystem 1 [list load [file join $dir libfilesystem.so.1.1]]
    package ifneeded network 1 "source [list [file join $dir network.tcl]]; load [list [file join $dir libnetwork.so.1.20]]"
    package ifneeded logging 1 [list load [file join $dir liblogging.so.1.0]]
} else {
    package ifneeded network 1 [list source [file join $dir network.tcl]]
}
package ifneeded miscellaneous 1 [list source [file join $dir misc.tcl]]
package ifneeded threads 1 [list source [file join $dir threads.tcl]]
package ifneeded linetask 1 [list source [file join $dir linetask.tcl]]
package ifneeded moodsshelp 1 [list source [file join $dir htmldata.tcl]]
package ifneeded moodsshelp-ja 1 [list source [file join $dir htmldata-ja.tcl]]
package ifneeded hashes 1 [list source [file join $dir hashes.tcl]]
